@@ -4,5 +4,5 @@
 from __future__ import absolute_import
 from .kplr import TIME_BASELINE, EXPOSURE_TIMES
 from .data import Dataset
-from .mast import API
+from .api import API, KOI, Planet, Star, LightCurve, TargetPixelFile
 from . import ld
